Spatio.Model.ExportPdfr2Response (spatio_sdk v0.0.2)
Response shape when the export was uploaded to R2 (?storage=r2). The streaming case (?storage=stream, default) returns a binary application/pdf body and is not modeled as a JSON schema.
Summary
Types
@type t() :: %Spatio.Model.ExportPdfr2Response{ expiresAt: DateTime.t(), size: integer(), storage: String.t(), url: Uri }